@@ -2,7 +2,7 @@ from celery.task import task
 from django.core import management
 
 
-@task()
+@task(name='call_management_command')
 def call_management_command(command):
     """
     Run a management command as a Celery task.
